@@ -62,6 +62,13 @@ def commit_configs(
     Parses configs, runs semantic validations, and creates a validation or validated
     model based on `is_validation`
     """
+    # Sometimes people accidentally override their local TRANSFORM_API_URL
+    # environment variable with an empty string instead of UNSET-ing it.
+    # And then an empty string propagates all the way here. So if api_url
+    # is empty, default it. It's worth noting that in python "" evaluates to
+    # false, which is why this oneliner works.
+    api_url = api_url or TRANSFORM_API_URL
+
     # get the config files
     yaml_files = read_config_files(config_dir)
     results = {"yaml_files": yaml_files}
